pub struct ExifEntry {
pub namespace: Namespace,
pub ifd: IfdEntry,
pub tag: ExifTag,
pub value: TagValue,
pub unit: Cow<'static, str>,
pub value_more_readable: Cow<'static, str>,
pub kind: IfdKind,
}Expand description
Structure that represents a parsed EXIF tag.
Fields
namespace: NamespaceNamespace of the tag. If Standard (0x0000), it is an EXIF tag defined in the
official standard. Other namespaces accomodate manufacturer-specific tags that
may be embedded in MarkerNote blob tag.
ifd: IfdEntryLow-level IFD entry that contains the EXIF tag. The client may look into this
structure to get tag’s raw data, or to parse the tag herself if tag is UnknownToMe.
tag: ExifTagEXIF tag type as an enumeration. If UnknownToMe, the crate did not know the
tag in detail, and parsing will be incomplete. The client may read into
ifd to discover more about the unparsed tag.
value: TagValueEXIF tag value as an enumeration. Behaves as a “variant” value
unit: Cow<'static, str>Unit of the value, if applicable. If tag is UnknownToMe, unit will be empty.
If the tag has been parsed and it is indeed unitless, it will be "none".
Note that
unit refers to the contents of value, not to the readable string. For example,
a GPS latitude is a triplet of rational values, so unit is D/M/S, even though
value_more_readable contains a single string with all three parts
combined.
value_more_readable: Cow<'static, str>Human-readable and “pretty” version of value.
Enumerations and tuples are interpreted and combined. If value
has a unit, it is also added.
If tag is UnknownToMe, this member contains tag ID.
kind: IfdKind